@@ -43,6 +43,7 @@
 #include "frame-private.h"
 #include "group.h"
 #include <X11/Xatom.h>
+#include <X11/extensions/XRes.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -395,11 +396,57 @@ reload_wm_window_role (MetaWindow    *window,
     window->role = g_strdup (value->v.str);
 }
 
+static pid_t
+get_local_pid (MetaWindow *window)
+{
+  pid_t pid;
+  XResClientIdSpec spec;
+  long num_ids;
+  XResClientIdValue *client_ids;
+  long i;
+
+  pid = -1;
+
+  spec.client = window->xwindow;
+  spec.mask = XRES_CLIENT_ID_PID_MASK;
+
+  XResQueryClientIds (window->display->xdisplay,
+                      1,
+                      &spec,
+                      &num_ids,
+                      &client_ids);
+
+  for (i = 0; i < num_ids; i++)
+    {
+      if (client_ids[i].spec.mask == XRES_CLIENT_ID_PID_MASK)
+        {
+          pid = XResGetClientPid (&client_ids[i]);
+          break;
+        }
+    }
+
+  XResClientIdsDestroy (num_ids, client_ids);
+
+  return pid;
+}
+
 static void
 reload_net_wm_pid (MetaWindow    *window,
                    MetaPropValue *value,
                    gboolean       initial)
 {
+  pid_t pid;
+
+  pid = get_local_pid (window);
+
+  if (pid != -1)
+    {
+      meta_verbose ("Ignoring _NET_WM_PID in favor of XResGetClientPid\n");
+
+      window->net_wm_pid = pid;
+      return;
+    }
+
   if (value->type != META_PROP_VALUE_INVALID)
     {
       gulong cardinal = (int) value->v.cardinal;
